@@ -11,6 +11,11 @@ def get_current():
     return jezdzenka.table.search(ticket.archived == False)
 
 
+def get_archived():
+    ticket = Query()
+    return jezdzenka.table.search(ticket.archived == True)
+
+
 def get_all_by_tag(all_tag):
     return jezdzenka.table.search(Query().tags.any(all_tag))
 
@@ -24,5 +29,9 @@ def get_filename_by_id(doc_id: int):
     return jezdzenka.table.get(doc_id=int(doc_id))['filename']
 
 
+def get_archived_status_by_id(doc_id: int):
+    return jezdzenka.table.get(doc_id=int(doc_id))['archived']
+
+
 def get_object_by_id(doc_id: int):
     return jezdzenka.table.get(doc_id=int(doc_id))
